@@ -133,9 +133,10 @@ class BaseConstructor(object):
             old_deep = self.deep_construct
             self.deep_construct = True
         if node in self.recursive_objects:
-            raise ConstructorError(
-                None, None, 'found unconstructable recursive node', node.start_mark
-            )
+            return self.recursive_objects[node]
+            # raise ConstructorError(
+            #     None, None, 'found unconstructable recursive node', node.start_mark
+            # )
         self.recursive_objects[node] = None
         constructor = None  # type: Any
         tag_suffix = None
@@ -914,6 +915,7 @@ class Constructor(SafeConstructor):
         # Format:
         #   !!python/object:module.name { ... state ... }
         instance = self.make_python_instance(suffix, node, newobj=True)
+        self.recursive_objects[node] = instance
         yield instance
         deep = hasattr(instance, '__setstate__')
         state = self.construct_mapping(node, deep=deep)
@@ -1561,6 +1563,17 @@ class RoundTripConstructor(SafeConstructor):
                 data2.yaml_set_tag(node.tag)
                 yield data2
                 return
+            elif isinstance(node, SequenceNode):
+                data3 = CommentedSeq()
+                data3._yaml_set_line_col(node.start_mark.line, node.start_mark.column)
+                if node.flow_style is True:
+                    data3.fa.set_flow_style()
+                elif node.flow_style is False:
+                    data3.fa.set_block_style()
+                data3.yaml_set_tag(node.tag)
+                yield data3
+                data3.extend(self.construct_sequence(node))
+                return
         except:  # NOQA
             pass
         raise ConstructorError(
